#### Remove Overlap

“Path” → “Remove Overlap” removes the overlap of the selected paths, or all paths if none are selected, or multiple glyphs are selected.
It also clears the selected glyphs of all open paths and stray nodes.
The filter expects all outline orientations to be set correctly (see Controlling Path Direction).

Apply this filter as a custom parameter with the `RemoveOverlap` name and no arguments.
Alternatively, apply “Remove Overlap” by checking its checkbox in the export dialog.